@@ -1,11 +1,11 @@
-__version__ = "2.36.0"
+__version__ = "2.40.1"
 
 from .rapidata_client import (
     RapidataClient,
     DemographicSelection,
     LabelingSelection,
     EffortSelection,
-    RetrievalMode,
+    RapidataRetrievalMode,
     ValidationSelection,
     ConditionalValidationSelection,
     CappedSelection,
@@ -38,9 +38,10 @@ from .rapidata_client import (
     Box,
     Datapoint,
     PromptMetadata,
-    logger,
-    configure_logger,
-    RapidataOutputManager,
     FailedUploadException,
     rapidata_config,
+    logger,
+    managed_print,
 )
+
+from . import types
