@@ -6,7 +6,7 @@ from .selection import (
     ConditionalValidationSelection,
     CappedSelection,
     ShufflingSelection,
-    RetrievalMode,
+    RapidataRetrievalMode,
     EffortSelection,
 )
 from .datapoints import Datapoint
@@ -43,9 +43,6 @@ from .filter import (
     OrFilter,
     ResponseCountFilter,
 )
-
-from .logging import configure_logger, logger, RapidataOutputManager
-
 from .validation import Box
 from .exceptions import FailedUploadException
-from .config import rapidata_config
+from .config import rapidata_config, logger, managed_print
