@@ -1,7 +1,11 @@
-from rapidata.api_client.models.prompt_asset_metadata_input import PromptAssetMetadataInput
+from rapidata.api_client.models.prompt_asset_metadata_input import (
+    PromptAssetMetadataInput,
+)
 from rapidata.api_client.models.url_asset_input import UrlAssetInput
 from rapidata.rapidata_client.datapoints.metadata._base_metadata import Metadata
-from rapidata.api_client.models.prompt_asset_metadata_input_asset import PromptAssetMetadataInputAsset
+from rapidata.api_client.models.prompt_asset_metadata_input_asset import (
+    PromptAssetMetadataInputAsset,
+)
 
 
 class MediaAssetMetadata(Metadata):
@@ -12,11 +16,8 @@ class MediaAssetMetadata(Metadata):
 
     def to_model(self):
         return PromptAssetMetadataInput(
-            _t="PromptAssetMetadataInput", 
+            _t="PromptAssetMetadataInput",
             asset=PromptAssetMetadataInputAsset(
-                actual_instance=UrlAssetInput(
-                    _t="UrlAssetInput", 
-                    url=self._url
-                )
-            )
+                actual_instance=UrlAssetInput(_t="UrlAssetInput", url=self._url)
+            ),
         )
