@@ -1,4 +1,4 @@
-from rapidata.rapidata_client.datapoints.datapoint import Datapoint
+from rapidata.rapidata_client.datapoints._datapoint import Datapoint
 from rapidata.rapidata_client.datapoints.assets import TextAsset, MediaAsset
 from rapidata.service import LocalFileService
 from rapidata.service.openapi_service import OpenAPIService
@@ -6,17 +6,16 @@ from concurrent.futures import ThreadPoolExecutor, as_completed
 from tqdm import tqdm
 
 from typing import Generator
-from rapidata.rapidata_client.logging import (
-    logger,
-    managed_print,
-    RapidataOutputManager,
-)
+from rapidata.rapidata_client.config import logger, managed_print
 import time
 import threading
-from rapidata.rapidata_client.api.rapidata_exception import (
+from rapidata.rapidata_client.api.rapidata_api_client import (
     suppress_rapidata_error_logging,
 )
-from rapidata.rapidata_client.config.config import rapidata_config
+from rapidata.rapidata_client.config.rapidata_config import rapidata_config
+
+# Add OpenTelemetry context imports for thread propagation
+from opentelemetry import context as otel_context
 
 
 def chunk_list(lst: list, chunk_size: int) -> Generator:
@@ -62,22 +61,37 @@ class RapidataDataset:
             )
             return datapoint
 
+        def upload_with_context(
+            context: otel_context.Context, datapoint: Datapoint, index: int
+        ) -> Datapoint:
+            """Wrapper function that runs upload_text_datapoint with the provided context."""
+            token = otel_context.attach(context)
+            try:
+                return upload_text_datapoint(datapoint, index)
+            finally:
+                otel_context.detach(token)
+
         successful_uploads: list[Datapoint] = []
         failed_uploads: list[Datapoint] = []
 
+        # Capture the current OpenTelemetry context before creating threads
+        current_context = otel_context.get_current()
+
         total_uploads = len(datapoints)
         with ThreadPoolExecutor(
-            max_workers=rapidata_config.max_upload_workers
+            max_workers=rapidata_config.upload.maxWorkers
         ) as executor:
             future_to_datapoint = {
-                executor.submit(upload_text_datapoint, datapoint, index=i): datapoint
+                executor.submit(
+                    upload_with_context, current_context, datapoint, i
+                ): datapoint
                 for i, datapoint in enumerate(datapoints)
             }
 
             with tqdm(
                 total=total_uploads,
                 desc="Uploading text datapoints",
-                disable=RapidataOutputManager.silent_mode,
+                disable=rapidata_config.logging.silent_mode,
             ) as pbar:
                 for future in as_completed(future_to_datapoint.keys()):
                     datapoint = future_to_datapoint[future]
@@ -119,7 +133,7 @@ class RapidataDataset:
         urls = datapoint.get_urls()
 
         last_exception = None
-        for attempt in range(rapidata_config.upload_max_retries):
+        for attempt in range(rapidata_config.upload.maxRetries):
             try:
                 with suppress_rapidata_error_logging():
                     self.openapi_service.dataset_api.dataset_dataset_id_datapoints_post(
@@ -136,7 +150,7 @@ class RapidataDataset:
 
             except Exception as e:
                 last_exception = e
-                if attempt < rapidata_config.upload_max_retries - 1:
+                if attempt < rapidata_config.upload.maxRetries - 1:
                     # Exponential backoff: wait 1s, then 2s, then 4s
                     retry_delay = 2**attempt
                     time.sleep(retry_delay)
@@ -144,13 +158,13 @@ class RapidataDataset:
                     logger.debug(
                         "Retrying %s of %s...",
                         attempt + 1,
-                        rapidata_config.upload_max_retries,
+                        rapidata_config.upload.maxRetries,
                     )
 
         # If we get here, all retries failed
         local_failed.append(datapoint)
         tqdm.write(
-            f"Upload failed for {datapoint} after {rapidata_config.upload_max_retries} attempts. \nFinal error: \n{str(last_exception)}"
+            f"Upload failed for {datapoint} after {rapidata_config.upload.maxRetries} attempts. \nFinal error: \n{str(last_exception)}"
         )
 
         return local_successful, local_failed
@@ -183,7 +197,7 @@ class RapidataDataset:
                 with tqdm(
                     total=total_uploads,
                     desc="Uploading datapoints",
-                    disable=RapidataOutputManager.silent_mode,
+                    disable=rapidata_config.logging.silent_mode,
                 ) as pbar:
                     prev_ready = 0
                     prev_failed = 0
@@ -291,17 +305,31 @@ class RapidataDataset:
         successful_uploads: list[Datapoint] = []
         failed_uploads: list[Datapoint] = []
 
+        def process_upload_with_context(
+            context: otel_context.Context, datapoint: Datapoint, index: int
+        ) -> tuple[list[Datapoint], list[Datapoint]]:
+            """Wrapper function that runs _process_single_upload with the provided context."""
+            token = otel_context.attach(context)
+            try:
+                return self._process_single_upload(datapoint, index)
+            finally:
+                otel_context.detach(token)
+
+        # Capture the current OpenTelemetry context before creating threads
+        current_context = otel_context.get_current()
+
         try:
             with ThreadPoolExecutor(
-                max_workers=rapidata_config.max_upload_workers
+                max_workers=rapidata_config.upload.maxWorkers
             ) as executor:
                 # Process uploads in chunks to avoid overwhelming the system
                 for chunk_idx, chunk in enumerate(chunk_list(datapoints, chunk_size)):
                     futures = [
                         executor.submit(
-                            self._process_single_upload,
+                            process_upload_with_context,
+                            current_context,
                             datapoint,
-                            index=(chunk_idx * chunk_size + i),
+                            chunk_idx * chunk_size + i,
                         )
                         for i, datapoint in enumerate(chunk)
                     ]
