@@ -1,5 +1,9 @@
-from typing import Literal, Optional, cast, Sequence
+from typing import Literal, Optional, Sequence
+import random
+import urllib.parse
+import webbrowser
 
+from colorama import Fore
 from rapidata.api_client.models.ab_test_selection_a_inner import AbTestSelectionAInner
 from rapidata.api_client.models.and_user_filter_model_filters_inner import (
     AndUserFilterModelFiltersInner,
@@ -11,14 +15,23 @@ from rapidata.api_client.models.create_order_model_referee import (
 from rapidata.api_client.models.create_order_model_workflow import (
     CreateOrderModelWorkflow,
 )
+from rapidata.api_client.models.sticky_state import StickyState
 
-from rapidata.rapidata_client.datapoints.datapoint import Datapoint
+from rapidata.rapidata_client.datapoints._datapoint import Datapoint
 from rapidata.rapidata_client.exceptions.failed_upload_exception import (
     FailedUploadException,
     _parse_failed_uploads,
 )
 from rapidata.rapidata_client.filter import RapidataFilter
-from rapidata.rapidata_client.logging import logger, managed_print
+from rapidata.rapidata_client.config import (
+    logger,
+    managed_print,
+    rapidata_config,
+    tracer,
+)
+from rapidata.rapidata_client.validation.validation_set_manager import (
+    ValidationSetManager,
+)
 from rapidata.rapidata_client.order._rapidata_dataset import RapidataDataset
 from rapidata.rapidata_client.order.rapidata_order import RapidataOrder
 from rapidata.rapidata_client.referee import Referee
@@ -27,6 +40,9 @@ from rapidata.rapidata_client.selection._base_selection import RapidataSelection
 from rapidata.rapidata_client.settings import RapidataSetting
 from rapidata.rapidata_client.workflow import Workflow
 from rapidata.service.openapi_service import OpenAPIService
+from rapidata.rapidata_client.api.rapidata_api_client import (
+    suppress_rapidata_error_logging,
+)
 
 
 class RapidataOrderBuilder:
@@ -47,7 +63,7 @@ class RapidataOrderBuilder:
         self._name = name
         self.order_id: str | None = None
         self.__openapi_service = openapi_service
-        self.__dataset: Optional[RapidataDataset]
+        self.__dataset: Optional[RapidataDataset] = None
         self.__workflow: Workflow | None = None
         self.__referee: Referee | None = None
         self.__validation_set_id: str | None = None
@@ -56,7 +72,12 @@ class RapidataOrderBuilder:
         self.__selections: list[RapidataSelection] = []
         self.__priority: int | None = None
         self.__datapoints: list[Datapoint] = []
-        self.__sticky_state: Literal["None", "Temporary", "Permanent"] | None = None
+        self.__sticky_state_value: Literal["None", "Temporary", "Permanent"] | None = (
+            None
+        )
+        self.__validation_set_manager: ValidationSetManager = ValidationSetManager(
+            self.__openapi_service
+        )
 
     def _to_model(self) -> CreateOrderModel:
         """
@@ -99,16 +120,82 @@ class RapidataOrderBuilder:
                 else None
             ),
             priority=self.__priority,
-            stickyState=self.__sticky_state,
+            stickyState=(
+                StickyState(self.__sticky_state_value)
+                if self.__sticky_state_value
+                else None
+            ),
         )
 
+    def _set_validation_set_id(self) -> bool:
+        """
+        Get the validation set ID for the order.
+
+        Returns:
+            bool: True if a new validation set was created, False otherwise.
+        """
+        assert self.__workflow is not None
+        if self.__validation_set_id:
+            logger.debug(
+                "Using specified validation set with ID: %s", self.__validation_set_id
+            )
+            return False
+
+        try:
+            with suppress_rapidata_error_logging():
+                self.__validation_set_id = (
+                    (
+                        self.__openapi_service.validation_api.validation_set_recommended_get(
+                            asset_type=[self.__datapoints[0].get_asset_type()],
+                            modality=[self.__workflow.modality],
+                            prompt_type=[
+                                t.value for t in self.__datapoints[0].get_prompt_type()
+                            ],
+                        )
+                    )
+                    .validation_sets[0]
+                    .id
+                )
+            logger.debug(
+                "Using recommended validation set with ID: %s", self.__validation_set_id
+            )
+            return False
+        except Exception as e:
+            logger.debug("No recommended validation set found, error: %s", e)
+
+        if (
+            len(self.__datapoints)
+            < rapidata_config.order.minOrderDatapointsForValidation
+        ):
+            logger.debug(
+                "No recommended validation set found, dataset too small to create one."
+            )
+            return False
+
+        logger.info("No recommended validation set found, creating new one.")
+
+        managed_print()
+        managed_print(f"No recommended validation set found, new one will be created.")
+        validation_set = self.__validation_set_manager._create_order_validation_set(
+            workflow=self.__workflow,
+            order_name=self._name,
+            datapoints=random.sample(
+                self.__datapoints,
+                min(
+                    rapidata_config.order.autoValidationSetSize, len(self.__datapoints)
+                ),
+            ),
+            settings=self.__settings,
+        )
+
+        logger.debug("New validation set created for order: %s", validation_set)
+        self.__validation_set_id = validation_set.id
+        return True
+
     def _create(self) -> RapidataOrder:
         """
         Create the Rapidata order by making the necessary API calls based on the builder's configuration.
 
-        Args:
-            max_upload_workers (int, optional): The maximum number of worker threads for processing media paths. Defaults to 10.
-
         Raises:
             ValueError: If both media paths and texts are provided, or if neither is provided.
             AssertionError: If the workflow is a CompareWorkflow and media paths are not in pairs.
@@ -116,6 +203,11 @@ class RapidataOrderBuilder:
         Returns:
             RapidataOrder: The created RapidataOrder instance.
         """
+        if rapidata_config.order.autoValidationSetCreation:
+            new_validation_set = self._set_validation_set_id()
+        else:
+            new_validation_set = False
+
         order_model = self._to_model()
         logger.debug("Creating order with model: %s", order_model)
 
@@ -126,6 +218,24 @@ class RapidataOrderBuilder:
         self.order_id = str(result.order_id)
         logger.debug("Order created with ID: %s", self.order_id)
 
+        if rapidata_config.order.autoValidationSetCreation and new_validation_set:
+            required_amount = min(int(len(self.__datapoints) * 0.01) or 1, 10)
+            managed_print()
+            managed_print(
+                Fore.YELLOW
+                + f"A new validation set was created. Please annotate {required_amount} datapoint{('s' if required_amount != 1 else '')} so the order runs correctly."
+                + Fore.RESET
+            )
+            link = f"https://app.{self.__openapi_service.environment}/validation-set/detail/{self.__validation_set_id}/annotate?orderId={self.order_id}&required={required_amount}"
+            could_open_browser = webbrowser.open(link)
+            if not could_open_browser:
+                encoded_url = urllib.parse.quote(link, safe="%/:=&?~#+!$,;'@()*[]")
+                managed_print(
+                    Fore.RED
+                    + f"Please open this URL in your browser: '{encoded_url}'"
+                    + Fore.RESET
+                )
+
         self.__dataset = (
             RapidataDataset(result.dataset_id, self.__openapi_service)
             if result.dataset_id
@@ -146,10 +256,11 @@ class RapidataOrderBuilder:
         logger.debug("Adding media to the order.")
 
         if self.__dataset:
-            _, failed_uploads = self.__dataset.add_datapoints(self.__datapoints)
+            with tracer.start_as_current_span("add_datapoints"):
+                _, failed_uploads = self.__dataset.add_datapoints(self.__datapoints)
 
-            if failed_uploads:
-                raise FailedUploadException(self.__dataset, order, failed_uploads)
+                if failed_uploads:
+                    raise FailedUploadException(self.__dataset, order, failed_uploads)
 
         else:
             raise RuntimeError(
@@ -358,5 +469,5 @@ class RapidataOrderBuilder:
                 "Sticky state must be of type Literal['None', 'Temporary', 'Permanent']."
             )
 
-        self.__sticky_state = sticky_state
+        self.__sticky_state_value = sticky_state
         return self
