@@ -1,3 +1,5 @@
+import json
+from typing import Any
 import requests
 from packaging import version
 from rapidata import __version__
@@ -15,7 +17,12 @@ from rapidata.rapidata_client.validation.validation_set_manager import (
 
 from rapidata.rapidata_client.demographic.demographic_manager import DemographicManager
 
-from rapidata.rapidata_client.logging import logger, managed_print
+from rapidata.rapidata_client.config import (
+    logger,
+    tracer,
+    managed_print,
+    rapidata_config,
+)
 
 
 class RapidataClient:
@@ -26,7 +33,7 @@ class RapidataClient:
         client_id: str | None = None,
         client_secret: str | None = None,
         environment: str = "rapidata.ai",
-        oauth_scope: str = "openid",
+        oauth_scope: str = "openid roles",
         cert_path: str | None = None,
         token: dict | None = None,
         leeway: int = 60,
@@ -46,37 +53,66 @@ class RapidataClient:
         Attributes:
             order (RapidataOrderManager): The RapidataOrderManager instance.
             validation (ValidationSetManager): The ValidationSetManager instance.
+            demographic (DemographicManager): The DemographicManager instance.
+            mri (RapidataBenchmarkManager): The RapidataBenchmarkManager instance.
         """
-        logger.debug("Checking version")
-        self._check_version()
+        with tracer.start_as_current_span("RapidataClient.__init__"):
+            logger.debug("Checking version")
+            self._check_version()
+            if environment != "rapidata.ai":
+                rapidata_config.logging.enable_otlp = False
 
-        logger.debug("Initializing OpenAPIService")
-        self._openapi_service = OpenAPIService(
-            client_id=client_id,
-            client_secret=client_secret,
-            environment=environment,
-            oauth_scope=oauth_scope,
-            cert_path=cert_path,
-            token=token,
-            leeway=leeway,
-        )
+            logger.debug("Initializing OpenAPIService")
+            self._openapi_service = OpenAPIService(
+                client_id=client_id,
+                client_secret=client_secret,
+                environment=environment,
+                oauth_scope=oauth_scope,
+                cert_path=cert_path,
+                token=token,
+                leeway=leeway,
+            )
 
-        logger.debug("Initializing RapidataOrderManager")
-        self.order = RapidataOrderManager(openapi_service=self._openapi_service)
+            logger.debug("Initializing RapidataOrderManager")
+            self.order = RapidataOrderManager(openapi_service=self._openapi_service)
 
-        logger.debug("Initializing ValidationSetManager")
-        self.validation = ValidationSetManager(openapi_service=self._openapi_service)
+            logger.debug("Initializing ValidationSetManager")
+            self.validation = ValidationSetManager(
+                openapi_service=self._openapi_service
+            )
 
-        logger.debug("Initializing DemographicManager")
-        self._demographic = DemographicManager(openapi_service=self._openapi_service)
+            logger.debug("Initializing DemographicManager")
+            self._demographic = DemographicManager(
+                openapi_service=self._openapi_service
+            )
 
-        logger.debug("Initializing RapidataBenchmarkManager")
-        self.mri = RapidataBenchmarkManager(openapi_service=self._openapi_service)
+            logger.debug("Initializing RapidataBenchmarkManager")
+            self.mri = RapidataBenchmarkManager(openapi_service=self._openapi_service)
+
+            self._check_beta_features()
 
     def reset_credentials(self):
         """Reset the credentials saved in the configuration file for the current environment."""
         self._openapi_service.reset_credentials()
 
+    def _check_beta_features(self):
+        """Enable beta features for the client."""
+        result: dict[str, Any] = json.loads(
+            self._openapi_service.api_client.call_api(
+                "GET",
+                f"https://auth.{self._openapi_service.environment}/connect/userinfo",
+            )
+            .read()
+            .decode("utf-8")
+        )
+        logger.debug("Userinfo: %s", result)
+        if result.get("role") != ["Admin"]:
+            logger.debug("User is not an admin, not enabling beta features")
+            return
+
+        logger.debug("User is an admin, enabling beta features")
+        rapidata_config.enableBetaFeatures = True
+
     def _check_version(self):
         try:
             response = requests.get(
@@ -91,5 +127,9 @@ class RapidataClient:
                         f"""A new version of the Rapidata SDK is available: {latest_version}
 Your current version is: {__version__}"""
                     )
+                else:
+                    logger.debug(
+                        "Current version is up to date. Version: %s", __version__
+                    )
         except Exception as e:
             logger.debug("Failed to check for updates: %s", e)
