@@ -5,6 +5,9 @@ from rapidata.api_client.models.simple_workflow_model_blueprint import (
 from rapidata.rapidata_client.workflow import Workflow
 from rapidata.api_client.models.compare_rapid_blueprint import CompareRapidBlueprint
 from rapidata.api_client.models.simple_workflow_model import SimpleWorkflowModel
+from rapidata.api_client import ComparePayload
+from rapidata.rapidata_client.datapoints._datapoint import Datapoint
+from rapidata.api_client.models.rapid_modality import RapidModality
 
 
 class CompareWorkflow(Workflow):
@@ -21,6 +24,8 @@ class CompareWorkflow(Workflow):
         instruction (str): The instruction to be used for comparison.
     """
 
+    modality = RapidModality.COMPARE
+
     def __init__(self, instruction: str, a_b_names: list[str] | None = None):
         super().__init__(type="CompareWorkflowConfig")
         self._instruction = instruction
@@ -44,3 +49,15 @@ class CompareWorkflow(Workflow):
             _t="SimpleWorkflow",
             blueprint=SimpleWorkflowModelBlueprint(blueprint),
         )
+
+    def _to_payload(self, datapoint: Datapoint) -> ComparePayload:
+        return ComparePayload(
+            _t="ComparePayload",
+            criteria=self._instruction,
+        )
+
+    def __str__(self) -> str:
+        return f"CompareWorkflow(instruction='{self._instruction}', a_b_names={self._a_b_names})"
+
+    def __repr__(self) -> str:
+        return f"CompareWorkflow(instruction={self._instruction!r}, a_b_names={self._a_b_names!r})"
